clear all
close all
clc

% Load examples
% load Library/a
load Library/i

A_int = flipud(a_targ(:)); Li = flipud(l_targ(:)); % Targets. Used only if you load examples from the Library

a0 = Sif; l0 = Lif; % seed functions. Used only if you load examples from the Library
% [ a0, l0 ] = getseedfunction( alip ); % Uncomment to find the seed function corresponding to the lip termination area among a predefined database

dl = 1; % set to 1 if you desire to estimate the length
norm_lips = 1; % set to 1 if the lip termination area is known. 
carea = 0; % weight of the kinetic energy constraint on the area function. positive number less than 1. Used only for dynamic inversion
cleng = 0; % weight of the kinetic energy constraint on the length function. positive number less than 1. Used only for dynamic inversion
cpot = 1e-4; % weight of the potential energy constraint on the length function. positive number less than 1.
thresh = 10*size(a0,2); % Cost-function threshold. 
Nbreak = 1000; % maximal number of iteration, to avoid infinite loops

if norm_lips == 0 % if lip termination is unconstrained, 
    
    load('Library/a00.mat')
    a0 = repmat(a_neutre,1,Ntrame);
    l0 = repmat(l_neutre,1,Ntrame);
    
end


[ ak1, lk1, fnest, err_form, titer ] = form2af( fn_targ, a0, l0, dl, norm_lips, carea, cleng, cpot, thresh, Nbreak );

figure;
plot([0;cumsum(lk1)], [ak1(1);ak1] ,'--k', 'linewidth',2) % Estimated area function
grid on; hold on;
plot([0;cumsum(Li)],[ A_int(1); A_int], 'k','linewidth',3) % Target, comment if you use your own data
plot([0;cumsum(l0(end:-1:1))], [a0(end);a0(end:-1:1)], '.-','linewidth',1) % Seed functions
set(gca, 'fontsize',20,'fontweight','bold')
xlabel('Distance from glottis (m)')
ylabel('Area function (m^2)')
legend('Estimated area function','Target area function','seed function')
set(gcf, 'units','normalized','position',[ 0 0 1 1 ])
figure; % Plot the cost function as a function of computation time
stem(titer, err_form, 'linewidth',2,'markerfacecolor','b','markeredgecolor','k')
hold on;
plot([0 titer(end)+1], thresh*ones(2,1), 'r','linewidth',2)
set(gca, 'fontsize',20,'fontweight','bold')
xlabel('Computation time (s)')
ylabel('L1-norm of the cost function (%)')
xlim([0 titer(end)+0.1])
set(gca, 'yscale','log')
legend('Cost-function','Threshold')
set(gcf, 'units','normalized','position',[ 0 0 1 1 ])